Documentation
¶
Overview ¶
cdktf-gke-auth
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GKEAuth_IsConstruct ¶
func GKEAuth_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NewGKEAuth_Override ¶
func NewGKEAuth_Override(g GKEAuth, scope constructs.Construct, id *string, props *ClusterInfo)
Types ¶
type AuthCredentials ¶
type ClusterInfo ¶
type GKEAuth ¶
type GKEAuth interface {
constructs.Construct
cdktf.ITerraformDependable
AuthCredentials() *AuthCredentials
ClientConfig() datagoogleclientconfig.DataGoogleClientConfig
ClusterCaCertificate() *string
ClusterCaCertificatePEM() *string
ClusterInfo() datagooglecontainercluster.DataGoogleContainerCluster
Context() *string
Fqn() *string
Host() *string
KubeConfigRaw() *string
// The tree node.
Node() constructs.Node
Token() *string
// Returns a string representation of this construct.
ToString() *string
}
func NewGKEAuth ¶
func NewGKEAuth(scope constructs.Construct, id *string, props *ClusterInfo) GKEAuth